@@ -406,9 +406,9 @@ class Query(Table, Monad):
         for tab in ljtables:
             tab.leftjoin = True
         
-        res.modify(lambda x: x.setWhere(False) if x.getTables() ^ ljtables else x, 'joincond')
+        res.modify(lambda x: x.setWhere(False) if x.getTables() ^ ljtables and not x.isExist() else x, 'joincond')
         for subq in res.subQueries():
-            subq.modify(lambda x: x.setWhere(False) if x.getTables() ^ ljtables else x, 'joincond')
+            subq.modify(lambda x: x.setWhere(False) if x.getTables() ^ ljtables and not x.isExist() else x, 'joincond')
         
         # res.modify(lambda x: x.setWhere(False), 'joincond')
         # ifcond = res.joincond.children.filter(lambda x: x.getTables() <= res.dependents())
